# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2023-09-28)
### Documentation
* Fixed su6 action badge ([`7ac72c3`](https://github.com/robinvandernoord/drive-in/commit/7ac72c3f1708f33d97a5859690b3f213e77fd2aa))

## v0.1.0 (2023-09-28)
### Feature
* Download should now work as well ([`530a237`](https://github.com/robinvandernoord/drive-in/commit/530a2376447d064b95ff1422d15e4c70951843ba))
* Boilerplate ([`ebcce5d`](https://github.com/robinvandernoord/drive-in/commit/ebcce5d26dec05b5632047fd150136fa8e71df38))

### Documentation
* Minor improvements ([`a61db1e`](https://github.com/robinvandernoord/drive-in/commit/a61db1e2952737fd22893a62163d03f7faef6888))
* Exlained features and limitations ([`4e6d1c9`](https://github.com/robinvandernoord/drive-in/commit/4e6d1c92e56fb4c8c81907ab670342a67af1598d))
* Added short description ([`6b87c36`](https://github.com/robinvandernoord/drive-in/commit/6b87c36597c3517b07e0e6c013bc7ad582febff0))
